OptRecordUpdate

Enum OptRecordUpdate 

pub enum OptRecordUpdate<R>
where R: Node,
{ NoChange, Clear, Set(R), Update { update: R::Update, insert: bool, }, }
Update for an optional record

Variants



NoChange

Do nothing



Clear

Remove the record.

If no record is present this is a noop.



Set(R)

Set the record to the provided value



Update

Update the record.

If no record is present, the insert flag controls whether a default record is inserted before applying the update.

Fields

update: R::Update

Update to apply to the record

insert: bool

Insert a default record if it is not set